0.9.9 API documentation: reciprocal.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

reciprocal.hpp
Go to the documentation of this file.
1
13 #pragma once
14
15 // Dependencies
16 #include "../detail/setup.hpp"
17
18 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
19 # pragma message("GLM: GLM_GTC_reciprocal extension included")
20 #endif
21
22 namespace glm
23 {
26
33 template<typename genType>
34 GLM_FUNC_DECL genType sec(genType angle);
35
42 template<typename genType>
43 GLM_FUNC_DECL genType csc(genType angle);
44
51 template<typename genType>
52 GLM_FUNC_DECL genType cot(genType angle);
53
60 template<typename genType>
61 GLM_FUNC_DECL genType asec(genType x);
62
69 template<typename genType>
70 GLM_FUNC_DECL genType acsc(genType x);
71
78 template<typename genType>
79 GLM_FUNC_DECL genType acot(genType x);
80
86 template<typename genType>
87 GLM_FUNC_DECL genType sech(genType angle);
88
94 template<typename genType>
95 GLM_FUNC_DECL genType csch(genType angle);
96
102 template<typename genType>
103 GLM_FUNC_DECL genType coth(genType angle);
104
111 template<typename genType>
112 GLM_FUNC_DECL genType asech(genType x);
113
120 template<typename genType>
121 GLM_FUNC_DECL genType acsch(genType x);
122
129 template<typename genType>
130 GLM_FUNC_DECL genType acoth(genType x);
131
133 }//namespace glm
134
135 #include "reciprocal.inl"
glm::sec
GLM_FUNC_DECL genType sec(genType angle)
Secant function.
glm::csc
GLM_FUNC_DECL genType csc(genType angle)
Cosecant function.
glm::coth
GLM_FUNC_DECL genType coth(genType angle)
Cotangent hyperbolic function.
glm::asec
GLM_FUNC_DECL genType asec(genType x)
Inverse secant function.
glm::angle
GLM_FUNC_DECL T angle(qua< T, Q > const &x)
Returns the quaternion rotation angle.
glm::cot
GLM_FUNC_DECL genType cot(genType angle)
Cotangent function.
glm::acsc
GLM_FUNC_DECL genType acsc(genType x)
Inverse cosecant function.
glm::sech
GLM_FUNC_DECL genType sech(genType angle)
Secant hyperbolic function.
glm::csch
GLM_FUNC_DECL genType csch(genType angle)
Cosecant hyperbolic function.
glm::acoth
GLM_FUNC_DECL genType acoth(genType x)
Inverse cotangent hyperbolic function.
glm::acot
GLM_FUNC_DECL genType acot(genType x)
Inverse cotangent function.
glm::asech
GLM_FUNC_DECL genType asech(genType x)
Inverse secant hyperbolic function.
glm::acsch
GLM_FUNC_DECL genType acsch(genType x)
Inverse cosecant hyperbolic function.
glm
Definition: common.hpp:20